@@ -5,13 +5,10 @@ Created on Tue Jan 27 23:13:42 2015, 2020
 @author: carolc24, Kyle Medley, hsauro
 """
 
-from __future__ import absolute_import, division, print_function, unicode_literals
+import simplesbml.tests.runTests as tests
 
 from .simplesbml import SbmlModel
 from .simplesbml import loadSBMLStr
 from .simplesbml import loadSBMLFile
 
 from simplesbml._version import __version__
-
-
-
